Payment Flow History

#### Day 01/01/12

Last balance | To receive | To pay | Received | Paid | Bal. expected | Bal. real
$436.00 | $ 0.00 | $20.00 | $ 0.00 | $ 0.00 | $416.00 | $436.00

# | Status | Description | Value | Paid/Received | Due date | Paid date
130 | To Pay | Test payment | $10.00 |  | 01/01/12 |
131 | Paid | Test payment | $10.00 | $10.00 | 01/01/12 | 01/02/12

#### Day 01/02/12

Last balance | To receive | To pay | Received | Paid | Bal. expected | Bal. real
$436.00 | $ 0.00 | $ 0.00 | $ 0.00 | $10.00 | $436.00 | $426.00

# | Status | Description | Value | Paid/Received | Due date | Paid date
131 | Paid | Test payment | $10.00 | $10.00 | 01/01/12 | 01/02/12